Module state

Module state 

Structs

AdminConfig
Automation
AutomationConditions
Conditions that gate whether an automation deploys in a given round.
Board
BoardV4 is a singleton account tracking global game state.
Config
Miner
ProtocolConfig
Round
Treasury
Treasury is a singleton account which is the mint authority for the ORE token and the authority of the program’s global token account.

Enums

AutomationStrategy
OreAccount

Functions

automation_pda
board_pda
config_pda
miner_pda
round_pda
stats_pda
treasury_pda
treasury_tokens_address