#[repr(C)]pub struct AutomationV4 {
pub amount: u64,
pub authority: Pubkey,
pub balance: u64,
pub executor: Pubkey,
pub fee: u64,
pub strategy: u64,
pub mask: u64,
pub reload: u64,
pub total_sol_spent: u64,
pub total_ore_earned: u64,
pub conditions: AutomationConditions,
}Fields
amount: u64The amount of SOL to deploy on each territory per round.
The authority of this automation account.
balance: u64The amount of SOL this automation has left.
executor: PubkeyThe executor of this automation account.
fee: u64The amount of SOL the executor should receive in fees.
strategy: u64The strategy this automation uses.
mask: u64The mask of squares this automation should deploy to if preferred strategy. If strategy is Random, first bit is used to determine how many squares to deploy to.
reload: u64Whether or not to auto-reload SOL winnings into the automation balance.
total_sol_spent: u64The total SOL spent (lost to fees) by this automation.
total_ore_earned: u64The total ORE earned by this automation.
conditions: AutomationConditionsConditions that must be met for the automation to deploy.
Implementations
Sourceimpl AutomationV4
impl AutomationV4