#[repr(C)]pub struct Miner {Show 17 fields
pub authority: Pubkey,
pub auto_return: u64,
pub checkpoint_id: u64,
pub checkpoint_fee: u64,
pub deployed: [u64; 25],
pub mass: [u64; 25],
pub cumulative: [u64; 25],
pub round_id: u64,
pub rewards_factor: Numeric,
pub rewards_sol: u64,
pub refined_ore: u64,
pub rewards_ore: u64,
pub last_claim_ore_at: i64,
pub last_claim_sol_at: i64,
pub lifetime_rewards_ore: u64,
pub lifetime_deployed: u64,
pub lifetime_rewards_sol: u64,
}Fields
The authority of this miner account.
auto_return: u64Whether or not to auto-return SOL winnings to the miner’s wallet.
checkpoint_id: u64The checkpoint ID.
checkpoint_fee: u64SOL witheld in reserve to pay for checkpointing.
deployed: [u64; 25]The amount of SOL deployed on each square. TODO: Rename to sol.
mass: [u64; 25]The amount of SOL deployed on each square, weighted by the time remaining when deployed.
cumulative: [u64; 25]The cumulative mass on each square prior to this miner’s deployment on that square. TODO: Rename to mass_cumulative.
round_id: u64The round ID.
rewards_factor: NumericThe rewards factor last time rewards were updated on this miner account.
rewards_sol: u64The amount of SOL this miner has had returned and may claim. TODO: Rename to sol_returned.
refined_ore: u64The amount of ORE this miner has earned from refining fees and may claim. TODO: Rename to ore_refined.
rewards_ore: u64The amount of ORE this miner has mined and may claim. TODO: Rename to ore_unrefined.
last_claim_ore_at: i64The last time this miner claimed ORE rewards.
last_claim_sol_at: i64The last time this miner claimed SOL rewards.
lifetime_rewards_ore: u64The total amount of ORE this miner has mined across all blocks. TODO: Rename to lifetime_rewards_ore.
lifetime_deployed: u64The total amount of SOL this miner has deployed across all rounds.
lifetime_rewards_sol: u64The total amount of SOL this miner has mined across all blocks. TODO: Rename to lifetime_returned_sol.
Implementations