#[repr(C)]pub struct MinerV1 {Show 15 fields
pub authority: Pubkey,
pub deployed: [u64; 25],
pub cumulative: [u64; 25],
pub checkpoint_fee: u64,
pub checkpoint_id: u64,
pub last_claim_ore_at: i64,
pub last_claim_sol_at: i64,
pub rewards_factor: Numeric,
pub rewards_sol: u64,
pub rewards_ore: u64,
pub refined_ore: u64,
pub round_id: u64,
pub lifetime_rewards_sol: u64,
pub lifetime_rewards_ore: u64,
pub lifetime_deployed: u64,
}Fields
The authority of this miner account.
deployed: [u64; 25]The miner’s prospects in the current round.
cumulative: [u64; 25]The cumulative amount of SOL deployed on each square prior to this miner’s move.
checkpoint_fee: u64SOL witheld in reserve to pay for checkpointing.
checkpoint_id: u64The last round that this miner checkpointed.
last_claim_ore_at: i64The last time this miner claimed ORE rewards.
last_claim_sol_at: i64The last time this miner claimed SOL rewards.
rewards_factor: NumericThe rewards factor last time rewards were updated on this miner account.
rewards_sol: u64The amount of SOL this miner can claim.
rewards_ore: u64The amount of ORE this miner can claim.
refined_ore: u64The amount of ORE this miner has earned from claim fees.
round_id: u64The ID of the round this miner last played in.
lifetime_rewards_sol: u64The total amount of SOL this miner has mined across all blocks.
lifetime_rewards_ore: u64The total amount of ORE this miner has mined across all blocks.
lifetime_deployed: u64The total amount of SOL this miner has deployed across all rounds.
Implementations
Sourceimpl MinerV1
impl MinerV1
pub fn pda(&self) -> (Pubkey, u8)
pub fn claim_ore_v1(&mut self, clock: &Clock, treasury: &mut TreasuryV1) -> u64
pub fn claim_ore_v4(&mut self, clock: &Clock, treasury: &mut TreasuryV4) -> u64
pub fn claim_sol(&mut self, clock: &Clock) -> u64
pub fn update_rewards_v1(&mut self, treasury: &TreasuryV1)
pub fn update_rewards_v4(&mut self, treasury: &TreasuryV4)