#[repr(C)]pub struct MinerV4 {Show 17 fields
pub authority: Pubkey,
pub auto_return: u64,
pub checkpoint_id: u64,
pub checkpoint_fee: u64,
pub sol: [u64; 25],
pub mass: [u64; 25],
pub mass_cumulative: [u64; 25],
pub round_id: u64,
pub rewards_factor: Numeric,
pub sol_returned: u64,
pub ore_refined: u64,
pub ore_unrefined: u64,
pub last_claim_ore_at: i64,
pub last_claim_sol_at: i64,
pub lifetime_rewards: u64,
pub lifetime_deployed: u64,
pub lifetime_returned_sol: u64,
}Fields
The authority of this miner account.
auto_return: u64Whether or not to auto-return SOL winnings to the miner’s wallet.
checkpoint_id: u64The checkpoint ID.
checkpoint_fee: u64SOL witheld in reserve to pay for checkpointing.
sol: [u64; 25]The amount of SOL deployed on each square.
mass: [u64; 25]The amount of SOL deployed on each square, weighted by the time remaining when deployed.
mass_cumulative: [u64; 25]The cumulative mass on each square prior to this miner’s deployment on that square.
round_id: u64The round ID.
rewards_factor: NumericThe rewards factor last time rewards were updated on this miner account.
sol_returned: u64The amount of SOL this miner has had returned and may claim.
ore_refined: u64The amount of ORE this miner has earned from refining fees and may claim.
ore_unrefined: u64The amount of ORE this miner has mined and may claim.
last_claim_ore_at: i64The last time this miner claimed ORE rewards.
last_claim_sol_at: i64The last time this miner claimed SOL rewards.
lifetime_rewards: u64The total amount of ORE this miner has mined across all blocks.
lifetime_deployed: u64The total amount of SOL this miner has deployed across all rounds.
lifetime_returned_sol: u64The total amount of SOL this miner has mined across all blocks.
Implementations
Sourceimpl MinerV4
impl MinerV4
pub fn pda(&self) -> (Pubkey, u8)
pub fn claim_ore_v1(&mut self, clock: &Clock, treasury: &mut TreasuryV1) -> u64
pub fn claim_ore_v4(&mut self, clock: &Clock, treasury: &mut TreasuryV4) -> u64
pub fn claim_sol(&mut self, clock: &Clock) -> u64
pub fn update_rewards_v4(&mut self, treasury: &TreasuryV4)
pub fn update_rewards_v1(&mut self, treasury: &TreasuryV1)