#[repr(C)]pub struct RoundV4 {Show 13 fields
pub id: u64,
pub deployed: [u64; 25],
pub mass: [u64; 25],
pub count: [u64; 25],
pub slot_hash: [u8; 32],
pub expires_at: u64,
pub motherlode: u64,
pub rent_payer: Pubkey,
pub rewards: [u64; 25],
pub total_vaulted: u64,
pub total_winnings: u64,
pub total_miners: u64,
pub top_miner: Pubkey,
}Fields
id: u64The round number.
deployed: [u64; 25]The amount of SOL deployed in each square. TODO: Rename to sol.
mass: [u64; 25]The amount of mass deployed in each square.
count: [u64; 25]The number of unique miners on each square. TODO rename to miners.
slot_hash: [u8; 32]The entropy value. TODO: Rename to entropy.
expires_at: u64The slot after which this account may be closed. TODO: Rename to closes_at.
motherlode: u64The amount of ORE distributed as the motherlode reward.
rent_payer: PubkeyThe account to which rent should be returned to when this account is closed.
rewards: [u64; 25]The amount of ORE to distribute to miners.
total_vaulted: u64The total SOL collected by the protocol. TODO: Rename to protocol_fee.
total_winnings: u64The total SOL returned to miners. TODO: Rename to total_returned.
total_miners: u64The total number of unique miners that played in the round. TODO rename to unique_miners.
top_miner: PubkeyThe winner of the solo reward. TODO: Rename to winner.
Implementations
Sourceimpl RoundV4
impl RoundV4
pub fn pda(&self) -> (Pubkey, u8)
pub fn rng(&self) -> Option<u64>
pub fn winning_square(&self, rng: u64) -> usize
pub fn top_miner_sample(&self, rng: u64, winning_square: usize) -> u64
pub fn calculate_total_winnings(&self, winning_square: usize) -> u64
pub fn is_split_reward(&self, rng: u64) -> bool
pub fn did_hit_motherlode(&self, rng: u64) -> bool
pub fn total_deployed(&self) -> u64
pub fn top_miner_reward(&self) -> u64