#[repr(C)]pub struct TreasuryV1 {
pub balance: u64,
pub buffer_a: u64,
pub motherlode: u64,
pub miner_rewards_factor: Numeric,
pub stake_rewards_factor: Numeric,
pub buffer_b: u64,
pub total_refined: u64,
pub total_staked: u64,
pub total_unclaimed: u64,
}Expand description
Treasury is a singleton account which is the mint authority for the ORE token and the authority of the program’s global token account.
Fields
balance: u64buffer_a: u64Buffer a (placeholder)
motherlode: u64The amount of ORE in the motherlode rewards pool.
miner_rewards_factor: NumericThe cumulative ORE distributed to miners, divided by the total unclaimed ORE at the time of distribution.
stake_rewards_factor: Numeric👎Deprecated since 3.8.0:
Staking has moved to ore-stake program
The cumulative ORE distributed to stakers, divided by the total stake at the time of distribution.
buffer_b: u64Buffer b (placeholder)
total_refined: u64The current total amount of refined ORE mining rewards.
total_staked: u64👎Deprecated since 3.8.0:
Staking has moved to ore-stake program
The current total amount of ORE staking deposits.
total_unclaimed: u64The current total amount of unclaimed ORE mining rewards.
Implementations