#[repr(C)]pub struct TreasuryV4 {
pub motherlode: u64,
pub rewards_factor: Numeric,
pub total_refined: u64,
pub total_unrefined: u64,
}Expand description
Treasury is a singleton account which is the mint authority for the ORE token and the authority of the program’s global token account.
Fields
motherlode: u64The amount of ORE in the motherlode rewards pool.
rewards_factor: NumericThe cumulative ORE distributed to miners, divided by the total unclaimed ORE at the time of distribution.
total_refined: u64The current total amount of refined ORE mining rewards.
total_unrefined: u64The current total amount of unrefined ORE mining rewards.
Implementations