Module state

Module state 

Structs

AdminConfig
AutomationConditions
Conditions that gate whether an automation deploys in a given round.
AutomationV1
AutomationV4
BoardV1
BoardV4
BoardV4 is a singleton account tracking global game state.
ConfigV1
ConfigV4
MinerV1
MinerV4
ProtocolConfig
RoundV1
RoundV4
TreasuryV1
Treasury is a singleton account which is the mint authority for the ORE token and the authority of the program’s global token account.
TreasuryV4
Treasury is a singleton account which is the mint authority for the ORE token and the authority of the program’s global token account.

Enums

Automation
AutomationStrategy
Board
Config
Miner
OreAccountV1
OreAccountV4
Round
Treasury

Functions

automation_pda
board_pda
config_pda
miner_pda
round_pda
stats_pda
treasury_pda
treasury_tokens_address