Module state

Module state 

Structs

AdminConfig
Automation
AutomationConditions
Conditions that gate whether an automation deploys in a given round.
AutomationV4
Board
BoardV4
BoardV4 is a singleton account tracking global game state.
Config
ConfigV4
Miner
MinerV4
ProtocolConfig
Round
RoundV4
Treasury
Treasury is a singleton account which is the mint authority for the ORE token and the authority of the program’s global token account.
TreasuryV4
Treasury is a singleton account which is the mint authority for the ORE token and the authority of the program’s global token account.

Enums

AutomationAccount
AutomationStrategy
BoardAccount
ConfigAccount
MinerAccount
OreAccount
OreAccountV4
RoundAccount
TreasuryAccount

Functions

automation_pda
board_pda
config_pda
miner_pda
round_pda
stats_pda
treasury_pda
treasury_tokens_address