#[repr(C)]pub struct RoundV4 {
pub id: u64,
pub sol: [u64; 25],
pub mass: [u64; 25],
pub miners: [u64; 25],
pub entropy: [u8; 32],
pub closes_at: u64,
pub motherlode: u64,
pub rent_payer: Pubkey,
pub rewards: [u64; 25],
pub protocol_fee: u64,
pub unique_miners: u64,
pub winner: Pubkey,
}Fields
id: u64The round number.
sol: [u64; 25]The amount of SOL deployed in each square.
mass: [u64; 25]The amount of mass deployed in each square.
miners: [u64; 25]The number of unique miners on each square.
entropy: [u8; 32]The entropy value.
closes_at: u64The slot after which this account may be closed.
motherlode: u64The amount of ORE distributed as the motherlode reward.
rent_payer: PubkeyThe account to which rent should be returned to when this account is closed.
rewards: [u64; 25]The amount of ORE to distribute to miners.
protocol_fee: u64The total SOL collected by the protocol.
unique_miners: u64The total number of unique miners that played in the round.
winner: PubkeyThe winner of the solo reward.
Implementations
Sourceimpl RoundV4
impl RoundV4
pub fn pda(&self) -> (Pubkey, u8)
pub fn rng(&self) -> Option<u64>
pub fn winning_square(&self, rng: u64) -> usize
pub fn top_miner_sample(&self, rng: u64, winning_square: usize) -> u64
pub fn calculate_total_winnings(&self, winning_square: usize) -> u64
pub fn is_split_reward(&self, rng: u64) -> bool
pub fn did_hit_motherlode(&self, rng: u64) -> bool